#!/bin/sh
#
# This script will test +24V and -48V power supply for minimum /
#  maximum tolerance voltage and current.
#  Script will check the PIC status to determind the voltage and current.
#
# Prerequisites:
#   NONE
#

TESTNUMBER=$1

################################################################################
# Give Usage Information
################################################################################
usage()
{
    echo "Usage: $0 {Test_Number}"
    echo "  Test_Number   - 1 thru 3"
    echo "      0 - both tests"
    echo "      1 - +24V"
    echo "      2 - -48V"
    exit 1
}

################################################################################
# Give Usage Information
################################################################################
set_time()
{
    echo
    echo "Enter the Date and Time in following format."
    echo "032713252007  (this is for 3/27/07 at 1:25 pm, use current date/time)"
    echo "Enter the Date and Time: "
    echo
    read DATE_TIME
    # set the system date and time
    date -s "$DATE_TIME"
    # sets the hardware clock to the above date/time
    hwclock -w
    date >> /var/log/atc300_install.log

#    echo "$0: Setting system time from HW clock."
#    hwclock -s
}

################################################################################
# Enter Operator ID
################################################################################
get_operator_id()
{
    echo
    echo "Enter your Operator Info: "
    read OPERTATOR_ID
    echo "ATC300 testing performed by: $OPERTATOR_ID" >> /var/log/atc300_power.log
}

################################################################################
# Enter Serial Number
# serial number will be provided at installation and saved to /Serial.txt.
################################################################################
get_serial_num()
{
    if [ -f /Serial.txt ]; then
        echo
        echo "ATC300 serial number: `cat /Serial.txt`" >> /var/log/atc300_power.log
    else
        echo
        echo "Enter ATC300 serial number: "
        read SERIAL_NUM
        echo "ATC300 serial number: $SERIAL_NUM" >> /var/log/atc300_power.log
        echo "$SERIAL_NUM" > /Serial.txt
    fi
}

################################################################################
# -48V & 24V test
# PIC return status = 0x11 0x9 0x41 0x0 0x14 0x9 0x7d 0x0
################################################################################
run_VI_test()
{
    if [ $TESTNUMBER -eq 1 ]; then
        VOLTAGE="+24V"
    elif [ $TESTNUMBER -eq 2 ]; then
        VOLTAGE="-48V"
    else
        exit 1
    fi

    timestamp=`date | sed "s/UTC //"`
    echo "$timestamp, Starting $VOLTAGE test." >> /var/log/atc300_power.log
    echo "Verify that INPUT POWER is set to $VOLTAGE and press y <ENTER>"
    read ANSWER

    if [ "$ANSWER" = "y" -o "$ANSWER" = "Y" ];then
        echo "Reading voltage for $VOLTAGE." >> /var/log/atc300_power.log

        # Retrieve PIC status
        PIC_STATUS=`/usr/bin/pictestapp 4 0`
        echo $PIC_STATUS >> /var/log/atc300_power.log

        #
        # check voltage
        #
        VOUT_HB=`echo "$PIC_STATUS" |cut -d ' ' -f 6`
        VOUT_LB=`echo "$PIC_STATUS" |cut -d ' ' -f 7`
        //VOUT_HEX=`printf "%x%x\n" $VOUT_HB $VOUT_LB`
        //VOUT_DEC=`printf "%d\n" 0x$VOUT_HEX`
        VOUT_DEC=`expr $(($VOUT_HB)) * 256 + $(($VOUT_LB))`
        VOUT_QUOTIENT=`expr $VOUT_DEC / 100`
        VOUT_REMAINDER=`expr $VOUT_DEC % 100`
        # +24V upper and lower 5% tolerance check
        if [ "$VOUT_DEC" -ge "2280" -a "$VOUT_DEC" -le "2520" ]; then
            echo "$VOLTAGE PASSED with "$VOUT_QUOTIENT"."$VOUT_REMAINDER"V."
            echo "$VOLTAGE PASSED with "$VOUT_QUOTIENT"."$VOUT_REMAINDER"V." >> /var/log/atc300_power.log
        else
            echo "$VOLTAGE FAILED with "$VOUT_QUOTIENT"."$VOUT_REMAINDER"V."
            echo "$VOLTAGE FAILED with "$VOUT_QUOTIENT"."$VOUT_REMAINDER"V." >> /var/log/atc300_power.log
            exit 1
        fi

        #
        # check current
        #
        IOUT_HB=`echo "$PIC_STATUS" |cut -d ' ' -f 8`
        IOUT_LB=`echo "$PIC_STATUS" |cut -d ' ' -f 9`
        //IOUT_HEX=`printf "%x%x\n" $IOUT_HB $IOUT_LB`
        //IOUT_DEC=`printf "%d\n" 0x$IOUT_HEX`
        IOUT_DEC=`expr $(($IOUT_HB)) * 256 + $(($IOUT_LB))`
        IOUT_QUOTIENT=`expr $IOUT_DEC / 100`
        IOUT_REMAINDER=`expr $IOUT_DEC % 100`
        # 2.5 Amp upper and lower 5% tolerance check
#        if [ "$IOUT_DEC" -ge "237" -a "$IOUT_DEC" -le "262" ]; then
            echo "$VOLTAGE PASSED with "$IOUT_QUOTIENT"."$IOUT_REMAINDER"A."
            echo "$VOLTAGE PASSED with "$IOUT_QUOTIENT"."$IOUT_REMAINDER"A." >> /var/log/atc300_power.log
#        else
#            echo "$VOLTAGE FAILED with "$IOUT_QUOTIENT"."$IOUT_REMAINDER"A."
#            echo "$VOLTAGE FAILED with "$IOUT_QUOTIENT"."$IOUT_REMAINDER"A." >> /var/log/atc300_power.log
#            exit 1
#        fi
    else
        echo "Wrong Voltage Setting. Try Again"
        exit 1
    fi
}


#
#Start main procedure
#

if [ $# -lt 1 ]; then
	usage
else
#    set_time
#    get_operator_id
    get_serial_num
    run_VI_test
fi
