#! /bin/sh
#
# swup_continue.sh :
# description: This script will perform the actual software upgrade on an ATC300-1000
#
# Return Codes
RET_OK=0
RET_NO_FILE=1
RET_CHECKSUM_ERR=2
RET_TAR_FAILURE=3
RET_UNKNOWN_CMD=9

# Set Variables
if [ -z "$BASE_DIR" ]; then
  BASE_DIR="/var/ascu/uploads"
fi
if [ -z "$SWUP_PACKAGE" ]; then
  SWUP_PACKAGE="swupdate.tar"
fi
if [ -z "$SWUP_COMMAND_FILE" ]; then
  SWUP_COMMAND_FILE="swupdate.cmd"
fi
if [ -z "$SWUP_SOURCE_DIR" ]; then
  SWUP_SOURCE_DIR="$BASE_DIR/uploads/update"
fi
if [ -z "$SWUP_SOURCE_FILE_DIR" ]; then
  SWUP_SOURCE_FILE_DIR="$BASE_DIR/uploads"
fi
if [ -f $BASE_DIR/version ]; then
  CURR_VERSION=`cat $BASE_DIR/version`
  cp $BASE_DIR/version $BASE_DIR/prev_version
else
  CURR_VERSION="??"
fi
NEW_VERSION="??"

export PATH=$SWUP_SOURCE_DIR:$PATH

# How are we called
case "$1" in
  check)
	if [ ! -f $SWUP_SOURCE_FILE_DIR/$SWUP_PACKAGE ]; then
	  echo "$RET_NO_FILE"
	  exit $RET_NO_FILE
	fi
	cd $SWUP_SOURCE_DIR
	tar xf $SWUP_SOURCE_FILE_DIR/$SWUP_PACKAGE > /dev/null 2> /dev/null
#	RESULT=$?
#	if [ "$RESULT" != "0" ]; then
#	  echo "$RET_TAR_FAILURE"
#	  exit $RET_TAR_FAILURE
#	fi
	#md5sum --status --check swupdate.md5
	RESULT=$?
	if [ "$RESULT" = "0" ]; then
	  if [ -f ./version ]; then
  	    NEW_VERSION=`cat ./version`
	  else
  	    NEW_VERSION="??"
	  fi
	  echo "Updated $CURR_VERSION to $NEW_VERSION"
	  rm $SWUP_SOURCE_FILE_DIR/$SWUP_PACKAGE
	  #exit $RET_OK
	else
	  echo "$RET_CHECKSUM_ERR"
	  exit $RET_CHECKSUM_ERR
	fi
        ;;
  continue)
	if [ -f ./version ]; then
  	  NEW_VERSION=`cat ./version`
	else
  	  NEW_VERSION="??"
	fi
        ;;
  abort)
	rm -rf $SWUP_SOURCE_DIR/*
	echo "$RET_OK"
	exit $RET_OK
        ;;
  *)
        #echo "$RET_UNKNOWN_CMD"
        #exit $RET_UNKNOWN_CMD
esac

RETVAL=0

IFS=:
while read CMD PARM1 PARM2; do
  echo -e "$CMD  $PARM1  $PARM2"
case "$CMD" in
  HALT)
	killall $PARM1
        ;;
  START)
	$PARM1 &
        ;;
  RUN)
#	$SWUP_SOURCE_DIR/$PARM1
	$PARM1
        ;;
  MKDIR)
	mkdir -p $PARM1
        ;;
  RMDIR)
	rmdir $PARM1
        ;;
  DEL)
	if [ -f $PARM1 ]; then
	   rm -f $PARM1
        fi
        ;;
  DEL_SRC)
	rm -f $SWUP_SOURCE_DIR/$PARM1
        ;;
  ADD)
	mv  $SWUP_SOURCE_DIR/$PARM1 $PARM2
        ;;
  ADD_IF_NEW)
	if [ ! -f $PARM2/$PARM1 ]; then
	   mv  $SWUP_SOURCE_DIR/$PARM1 $PARM2
        else
           rm  $SWUP_SOURCE_DIR/$PARM1
        fi
        ;;
  COPY)
	cp  $SWUP_SOURCE_DIR/$PARM1 $PARM2
        ;;
  LINK)
	ln -sf $PARM1 $PARM2
        ;;
  UPDATE)
	mv  $SWUP_SOURCE_DIR/$PARM1 $PARM2
        ;;
  REBOOT)
	reboot
        ;;
  SAVE)
	save
        ;;
  *)
        ;;
esac
done < $SWUP_SOURCE_DIR/$SWUP_COMMAND_FILE

exit $RETVAL

